### 0.12.7 {small}`2025-06-10`

```{rubric} Features
```
* Adds `algorithm_kwds` to `pp.neighbors` & `pp.bbknn` to fine-tune `ivfflat`, `ivfpq` & `nn_descent` {pr}`381` {smaller}`S Dicks`

```{rubric} Performance
```
* Speed up `pp.harmony_integrate` even more {pr}`379` {smaller}`S Dicks`

```{rubric} Bug fixes
```
* `key_added` will now be used as the key for `.uns` for `tl.leiden` and `tl.louvain` {pr}`378` {smaller}`S Dicks`


```{rubric} Misc
```
* Update the docker to use `python=3.13` and `rapids-25.06` {pr}`383` {smaller}`S Dicks`
* Update CI to run with `rapids-25.06` & `rapids-25.06-alpha` {pr}`383` {smaller}`S Dicks`
